﻿Imports System.IO
Imports System.IO.IsolatedStorage

Imports Petzold.Phone.EBookReader

    Partial Public Class MainPage
        Inherits PhoneApplicationPage
        Public Sub New()
            InitializeComponent()
        End Sub

        Private Sub OnButtonClick(ByVal sender As Object, ByVal args As RoutedEventArgs)
            ' Button.Content is book's friendly title
            ' Button.Tag is the book's filename
            Dim btn As Button = TryCast(sender, Button)
            Dim bookFilename As String = TryCast(btn.Tag, String)
            Dim infoFilename As String = Path.ChangeExtension(bookFilename, ".info")
            Dim book As BookInfo = BookInfo.Load(infoFilename)

            ' The BookInfo object will be null if the book has never been loaded 
            '      and hence doesn't yet exist in isolated storage.
            ' The BookInfo must be created from the raw Project Gutenberg text file.
            If book Is Nothing Then
                Dim buffer() As Byte = Nothing

                ' Transfer from resource to isolated storage
                Using stream As Stream = Application.GetResourceStream(New Uri("Books/" & bookFilename, UriKind.Relative)).Stream
                    buffer = New Byte(stream.Length - 1) {}
                    stream.Read(buffer, 0, buffer.Length)
                End Using
                Using isoStorage As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication()
                    Using stream As IsolatedStorageFileStream = isoStorage.CreateFile(bookFilename)
                        stream.Write(buffer, 0, buffer.Length)
                    End Using
                End Using

                ' Create new BookInfo object
                book = New BookInfo(infoFilename, bookFilename, TryCast(btn.Content, String))

                ' This shouldn't be necessary, but problems will result if it never gets saved
                book.Save()
            End If

            ' Store BookInfo object in App.CurrentBook property for reference by all pages
            TryCast(Application.Current, App).CurrentBook = book

            ' Navigate to the BookViewerPage
            Me.NavigationService.Navigate(New Uri("/BookViewerPage.xaml", UriKind.Relative))
        End Sub

        Protected Overrides Sub OnNavigatedTo(ByVal args As NavigationEventArgs)
            Dim book As BookInfo = (TryCast(Application.Current, App)).CurrentBook

            ' If we're navigating back here, and App.CurrentBook is != null,
            '  then we're done reading that book for now, and the BookInfo 
            '  file needs to be saved.
            If book IsNot Nothing Then
                book.Save()
                TryCast(Application.Current, App).CurrentBook = Nothing
            End If
            MyBase.OnNavigatedTo(args)
        End Sub
    End Class
